/*
 * @doc TYPE
 * @struct
 * Structure for storing exception information.  One of these structures
 * contains the information needed for one catch clause.
 *
 */

struct texceptioninfo
{
  #ifdef CLASSPERSIST
  PID pid;
  #endif
  uint16  u16StartPC;   /* @field Start PC of exception's effect */
  uint16  u16EndPC;     /* @field End PC of exception's effect */
  uint16  u16HandlerPC; /* @field PC of exception's handling code */
  tClassLoaderTuple* pstCatchType; /* @field Type of exception that this clause catches */
};
